player = {}

function makeRect(self)
		return { 
			left = self.x,
			right = self.x + (self.image:getWidth() * self.scale),
			top = self.y,
			bottom = self.y + (self.image:getWidth() * self.scale)
		}
end

function player.load(self, image)
	self.x        = love.graphics.getWidth()/2 - (image:getWidth()/2 * 0.3)
	self.y        = love.graphics.getHeight()/2 - (image:getHeight()/2 * 0.3)
	self.image    = image
	self.xvel     = 0
	self.yvel     = 0
	self.speed    = 2000
	self.friction = 3
	self.scale    = 0.3
	self.rect 	  = makeRect(self)
end

function player:draw()
	love.graphics.draw(self.image,self.x,self.y,0,self.scale,self.scale)
end

function player:move(dt)
	if love.keyboard.isDown("right") and self.xvel < self.speed then
		self.xvel = self.xvel + self.speed * dt
	end
	if love.keyboard.isDown("left") and self.xvel > -self.speed then
		self.xvel = self.xvel - self.speed * dt
	end
	if love.keyboard.isDown("down") and self.yvel < self.speed then
		self.yvel = self.yvel + self.speed * dt
	end
	if love.keyboard.isDown("up") and self.yvel > -self.speed then
		self.yvel = self.yvel - self.speed * dt 
	end
	self.y = self.y + self.yvel * dt
	if self.y < 0 then
		self.y = 0
		self.yvel = 0
	elseif self.y + (self.image:getHeight() * self.scale) > love.graphics.getHeight() then
		self.y = love.graphics.getHeight() - (self.image:getHeight() * self.scale)
		self.yvel = 0
	end
	if self.x > 10000 then
		self.x = 10000
		self.xvel = 0
	elseif self.x < -10000 then
		self.x = -10000
		self.xvel = 0
	end
	return self.xvel, dt
end

function player:physics(dt)
	self.xvel = self.xvel * (1 - math.min(dt * player.friction,1))
	self.yvel = self.yvel * (1 - math.min(dt * player.friction,1))
end

function player:setScale(scale)
	self.scale = scale
	self.x = love.graphics.getWidth()/2 - (image:getWidth()/2 * scale)
end

function player:collidiesWith(other)
	if not other.rect then
		other.rect = makeRect(other)
	end
	local lMost, rMost, bMost, tMost
	if self.rect.left < other.rect.left then
		lMost = self.rect
		rMost = other.rect
	else 
		lMost = other.rect
		rMost = self.rect
	end
	if self.rect.top < other.rect.top then
		tMost = self.rect
		bMost = other.rect
	else
		tMost = other.rect
		bMost = self.rect
	end
	local xdist = rMost.left - lMost.right
	local ydist = bMost.top - tMost.bottom
	return xdist <= 0 and ydist <= 0
end








